@@ -4,6 +4,9 @@ from .comment import Comment, CommentSummary
 from .page import Page, PageCategory
 from .picture import ProfilePictureSource, CoverPhoto
 from .post import Post
+from .video import Video, VideoCaption
+from .photo import Photo
+from .album import Album
 from .ig_basic_models import IgBasicUser, IgBasicMedia, IgBasicMediaChildren
 from .ig_pro_models import IgProUser, IgProMedia, IgProComment, IgProReply, IgProHashtag, IgProInsight
 
@@ -18,6 +21,10 @@ __all__ = [
     "PageCategory",
     "Post",
     "ProfilePictureSource",
+    "Video",
+    "VideoCaption",
+    "Photo",
+    "Album",
     # Instagram Basic display
     "IgBasicUser",
     "IgBasicMedia",
