@@ -5,6 +5,7 @@ from six import iteritems
 
 from attr import attrs, attrib
 from typing import List, Optional
+from requests.models import CaseInsensitiveDict
 
 try:
     from json.decoder import JSONDecodeError  # pragma: no cover
@@ -30,6 +31,8 @@ class RateLimitData(object):
     Refer: https://developers.facebook.com/docs/graph-api/overview/rate-limiting#headers
     """
     call_count = attrib(default=0, type=int)
+    call_volume = attrib(default=0, type=int)
+    cpu_time = attrib(default=0, type=int)
     total_cputime = attrib(default=0, type=int)
     total_time = attrib(default=0, type=int)
     type = attrib(default=None, type=Optional[str])
@@ -84,7 +87,7 @@ class RateLimit(object):
 
     @staticmethod
     def parse_headers(headers, key):
-        # type: (dict, str) -> Optional[dict]
+        # type: (CaseInsensitiveDict, str) -> Optional[dict]
         """
         Get rate limit information from header for key.
         :param headers: Response headers
@@ -102,7 +105,7 @@ class RateLimit(object):
         return None
 
     def set_limit(self, headers):
-        # type: (dict) -> None
+        # type: (CaseInsensitiveDict) -> None
         """
         Get rate limit data from response headers. And update to instance.
         :param headers: Response headers
